SpeakTrue

iOS Repository Inventory and Ownership (Complete)

Last refreshed: 2026-06-29

Scope

Path Category Ownership What it owns / edits
ios/Config/App.Debug.xcconfig build-config build and environment config xcconfig values and configuration docs used at build time.
ios/Config/App.Release.xcconfig build-config build and environment config xcconfig values and configuration docs used at build time.
ios/Config/README.md build-config build and environment config xcconfig values and configuration docs used at build time.
ios/SpeakTrue.xcodeproj/project.pbxproj project-metadata build system Xcode project/workspace metadata, scheme, and dependency lockfiles.
ios/SpeakTrue.xcodeproj/project.xcworkspace/contents.xcworkspacedata project-metadata build system Xcode project/workspace metadata, scheme, and dependency lockfiles.
ios/SpeakTrue.xcodeproj/project.xcworkspace/xcshareddata/swiftpm/Package.resolved project-metadata build system Xcode project/workspace metadata, scheme, and dependency lockfiles.
ios/SpeakTrue.xcodeproj/xcshareddata/xcschemes/SpeakTrue.xcscheme project-metadata build system Xcode project/workspace metadata, scheme, and dependency lockfiles.
ios/SpeakTrue.xcodeproj/xcuserdata/haddadios.xcuserdatad/xcschemes/xcschememanagement.plist project-metadata build system Xcode project/workspace metadata, scheme, and dependency lockfiles.
ios/SpeakTrue/AIDataSharingAgreementService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/AIDataSharingConsent.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/AIDataSharingConsentGateView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/AIProxyService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/AppTheme.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/AppTour.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/Assets.xcassets/AccentColor.colorset/Contents.json asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/100.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/102.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/1024.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/108.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/114.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/120.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/128.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/144.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/152.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/16.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/167.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/172.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/180.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/196.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/20.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/216.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/234.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/256.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/258.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/29.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/32.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/40.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/48.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/50.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/512.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/55.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/57.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/58.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/60.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/64.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/66.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/72.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/76.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/80.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/87.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/88.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/92.png asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/AppIcon.appiconset/Contents.json asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/Contents.json asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/Assets.xcassets/LaunchBackground.colorset/Contents.json asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/AsyncTimeout.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/AudioControlsView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/AudioPlayerService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/AudioRecorderService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/AuthGateView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/AuthService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/AuthState.swift state-model app runtime Typed feature state model used by UI and services.
ios/SpeakTrue/BreakManager.swift manager app runtime Cache/index lifecycle coordinator across app flows.
ios/SpeakTrue/CategoryInfo.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/CloudStorageService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/ColorExtension.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/ContentView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/DebugLogger.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/ElevenLabsSTTService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/ElevenLabsService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/GenerateButtonView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/HeaderViewSTT.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/HeaderViewTTS.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/Info.plist supporting-file app runtime Resource or generated helper outside main source.
ios/SpeakTrue/LiveVoiceAudioPlayer.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/LiveVoiceSTSService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/MainTabView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/Preview Assets.xcassets/Contents.json asset-or-plist design/build Static resources (icons, metadata, plist, non-executable assets).
ios/SpeakTrue/PronunciationGlossaryView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/PronunciationGlossaryViewModel.swift view-model app runtime UI-facing state machine and side-effect orchestration.
ios/SpeakTrue/RealtimeSTTService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/ResetButtonView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/SBCategoryDetailView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/STSViewModel.swift view-model app runtime UI-facing state machine and side-effect orchestration.
ios/SpeakTrue/STTViewModel.swift view-model app runtime UI-facing state machine and side-effect orchestration.
ios/SpeakTrue/SettingsModels.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SettingsTabView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/SettingsView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/ShareSheet.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SignInView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/SoundboardAudioClips.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SoundboardCacheIndex.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SoundboardCacheManager.swift manager app runtime Cache/index lifecycle coordinator across app flows.
ios/SpeakTrue/SoundboardCategories.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SoundboardView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/SoundboardViewModel.swift view-model app runtime UI-facing state machine and side-effect orchestration.
ios/SpeakTrue/SpeakTrue.entitlements supporting-file app runtime Resource or generated helper outside main source.
ios/SpeakTrue/SpeakTrueApp.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SpeechToSpeechView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/SpeechToTextView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/StartupLoadingView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/StorageManager.swift manager app runtime Cache/index lifecycle coordinator across app flows.
ios/SpeakTrue/StorageTestView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/SupabaseClientProvider.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/SupabaseConfig.swift config app runtime Runtime config binding and service bootstrap values.
ios/SpeakTrue/TTSCatSelectView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/TTSViewModel.swift view-model app runtime UI-facing state machine and side-effect orchestration.
ios/SpeakTrue/TextInputView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/TextToSpeechView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/UserSettings.swift swift app runtime Feature implementation utility (view, utility, or domain helper).
ios/SpeakTrue/UserSettingsSyncService.swift service app runtime Boundary abstraction for auth, storage, or runtime APIs.
ios/SpeakTrue/VoiceCloneTabView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/VoiceCloneViewModel.swift view-model app runtime UI-facing state machine and side-effect orchestration.
ios/SpeakTrue/VoiceModelSelectionView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrue/WaveFormView.swift screen app runtime SwiftUI screen/component used in navigation and feature shells.
ios/SpeakTrueTests/AIProxyModelCodingTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/AppContractsTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/AsyncTimeoutTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/AuthAndSessionTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/CloudStorageModelCodingTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/ColorExtensionTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/ConfigurationAndThemeTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/MainTabNavigationTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/STTAndSTSViewModelTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/SettingsContractsTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/SettingsDiffTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/SoundboardCacheManagerTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/SpeakTrueTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/TTSPlaybackModeBehaviorTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueTests/VoiceCloneViewModelValidationTests.swift unit-tests QA Unit tests for contracts, view models, and feature behaviors.
ios/SpeakTrueUITests/SpeakTrueUITests.swift ui-tests QA/integration UI/instrumentation tests for launch and screen-level flows.
ios/SpeakTrueUITests/SpeakTrueUITestsLaunchTests.swift ui-tests QA/integration UI/instrumentation tests for launch and screen-level flows.